﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;

namespace TabControlFullDatabinding
{
    public partial class Page : UserControl
    {
        public Page()
        {
            InitializeComponent();
            Loaded += new RoutedEventHandler(Page_Loaded);
        }

        void Page_Loaded(object sender, RoutedEventArgs e)
        {
            tabControl.ItemsSource = new List<Person>()
            {
                new Person()
                {
                    Name = "Joe Cryton",
                    Address = "4 Park Lane av. ",
                    DateOfBirth = new DateTime(1978, 5, 12)

                },

                new Person()
                {
                    Name = "Denis Lawson",
                    Address = "12 Woodgrave str",
                    DateOfBirth = new DateTime(1980, 12, 1)

                },

                new Person()
                {
                    Name = "Miles Rush",
                    Address = "7 Lake str.",
                    DateOfBirth = new DateTime(1985, 1, 20)

                }
            };
        }


    }

    public class Person:INotifyPropertyChanged
    {
        
        private String address;
        /// <summary>
        /// Gets or sets address of the person.
        /// </summary>
        public String Address
        {
            get
            {
                return this.address;
            }
            set
            {
                if (this.address != value)
                {
                    this.address = value;
                    OnPropertyChanged("Address");
                }
            }
        }
        
        private DateTime? dateOfBirth;
        /// <summary>
        /// Gets or sets the day of birth of the person.
        /// </summary>
        public DateTime? DateOfBirth
        {
            get
            {
                return this.dateOfBirth;
            }
            set
            {
                if (this.dateOfBirth != value)
                {
                    this.dateOfBirth = value;
                    OnPropertyChanged("DateOfBirth");
                }
            }
        }

        private String name;
        /// <summary>
        /// Gets or sets name of the person.
        /// </summary>
        public String Name
        {
            get
            {
                return this.name;
            }
            set
            {
                if (this.name != value)
                {
                    this.name = value;
                    OnPropertyChanged("Name");
                }
            }
        }

        /// <summary>
        ///     Called when the value of a property changes.
        /// </summary>
        /// <param name="propertyName">The name of the property that has changed.</param>
        protected virtual void OnPropertyChanged(String propertyName)
        {
            if (String.IsNullOrEmpty(propertyName))
            {
                return;
            }
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        /// <summary>
        ///     Raised when the value of one of the properties changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;
    }
}
